package VMOMI::HostProtocolEndpointPEType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
